# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: apeman/dal/tsdb/tsdb.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x61peman/dal/tsdb/tsdb.proto\x12\x0e\x63om.apeman.dal\"\x88\x01\n\x10\x43olumnDefinition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12&\n\x04type\x18\x02 \x01(\x0e\x32\x18.com.apeman.dal.DataType\x12\x12\n\x05limit\x18\x03 \x01(\x05H\x00\x88\x01\x01\x12\x14\n\x07nonNull\x18\x04 \x01(\x08H\x01\x88\x01\x01\x42\x08\n\x06_limitB\n\n\x08_nonNull\"\x19\n\tUniqueKey\x12\x0c\n\x04name\x18\x01 \x03(\t\"\xf7\x01\n\x15\x43reateDatafeedRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12-\n\x03tag\x18\x02 \x03(\x0b\x32 .com.apeman.dal.ColumnDefinition\x12/\n\x05\x66ield\x18\x03 \x03(\x0b\x32 .com.apeman.dal.ColumnDefinition\x12,\n\tuniqueKey\x18\x04 \x03(\x0b\x32\x19.com.apeman.dal.UniqueKey\x12\x33\n\ndataAmount\x18\x05 \x01(\x0e\x32\x1a.com.apeman.dal.DataAmountH\x00\x88\x01\x01\x42\r\n\x0b_dataAmount\"\x18\n\x16\x43reateDatafeedResponse\"\"\n\tTimestamp\x12\x15\n\repochInMillis\x18\x01 \x01(\x03\"\x87\x01\n\x03Val\x12\x0b\n\x01s\x18\x01 \x01(\tH\x00\x12\r\n\x03i64\x18\x02 \x01(\x03H\x00\x12\r\n\x03i32\x18\x03 \x01(\x05H\x00\x12\x0b\n\x01\x64\x18\x04 \x01(\x01H\x00\x12\x0b\n\x01\x66\x18\x05 \x01(\x02H\x00\x12\x0b\n\x01\x62\x18\x06 \x01(\x08H\x00\x12\'\n\x02ts\x18\x07 \x01(\x0b\x32\x19.com.apeman.dal.TimestampH\x00\x42\x05\n\x03Val\"B\n\nColumnMeta\x12\x0c\n\x04name\x18\x01 \x01(\t\x12&\n\x04type\x18\x02 \x01(\x0e\x32\x18.com.apeman.dal.DataType\"*\n\x05Tuple\x12!\n\x04\x63\x65ll\x18\x01 \x03(\x0b\x32\x13.com.apeman.dal.Val\"_\n\x0bTabularData\x12*\n\x06\x63olumn\x18\x01 \x03(\x0b\x32\x1a.com.apeman.dal.ColumnMeta\x12$\n\x05tuple\x18\x02 \x03(\x0b\x32\x15.com.apeman.dal.Tuple\"M\n\x0ePutDataRequest\x12\x10\n\x08\x64\x61tafeed\x18\x01 \x01(\t\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.com.apeman.dal.TabularData\"\x11\n\x0fPutDataResponse\":\n\x0cOutputColumn\x12\x0c\n\x04\x65xpr\x18\x01 \x01(\t\x12\x12\n\x05\x61lias\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_alias\"\xd7\x02\n\x0eGetDataRequest\x12\x10\n\x08\x64\x61tafeed\x18\x01 \x01(\t\x12,\n\x06\x63olumn\x18\x02 \x03(\x0b\x32\x1c.com.apeman.dal.OutputColumn\x12\x12\n\x05where\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07groupBy\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06having\x18\x05 \x01(\tH\x02\x88\x01\x01\x12\x14\n\x07orderBy\x18\x06 \x01(\tH\x03\x88\x01\x01\x12\x13\n\x06offset\x18\x07 \x01(\x03H\x04\x88\x01\x01\x12\x12\n\x05limit\x18\x08 \x01(\x03H\x05\x88\x01\x01\x12!\n\x04\x61rgs\x18\t \x03(\x0b\x32\x13.com.apeman.dal.Val\x12\x15\n\x08\x64istinct\x18\n \x01(\x08H\x06\x88\x01\x01\x42\x08\n\x06_whereB\n\n\x08_groupByB\t\n\x07_havingB\n\n\x08_orderByB\t\n\x07_offsetB\x08\n\x06_limitB\x0b\n\t_distinct\"N\n\x0fGetDataResponse\x12\x10\n\x08\x64\x61tafeed\x18\x01 \x01(\t\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.com.apeman.dal.TabularData\")\n\x15\x44\x65leteDatafeedRequest\x12\x10\n\x08\x64\x61tafeed\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteDatafeedResponse\"5\n\x13ListDatafeedRequest\x12\x13\n\x06\x66ilter\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\t\n\x07_filter\"\x90\x02\n\x0e\x44\x61tafeedResult\x12\x10\n\x08\x64\x61tafeed\x18\x01 \x01(\t\x12-\n\x03tag\x18\x02 \x03(\x0b\x32 .com.apeman.dal.ColumnDefinition\x12/\n\x05\x66ield\x18\x03 \x03(\x0b\x32 .com.apeman.dal.ColumnDefinition\x12,\n\tuniqueKey\x18\x04 \x03(\x0b\x32\x19.com.apeman.dal.UniqueKey\x12.\n\ndataAmount\x18\x05 \x03(\x0e\x32\x1a.com.apeman.dal.DataAmount\x12.\n\x0b\x63reatedTime\x18\x06 \x03(\x0b\x32\x19.com.apeman.dal.Timestamp\"H\n\x14ListDatafeedResponse\x12\x30\n\x08\x64\x61tafeed\x18\x01 \x03(\x0b\x32\x1e.com.apeman.dal.DatafeedResult\"&\n\x12GetDatafeedRequest\x12\x10\n\x08\x64\x61tafeed\x18\x01 \x01(\t\"Y\n\x13GetDatafeedResponse\x12\x35\n\x08\x64\x61tafeed\x18\x01 \x01(\x0b\x32\x1e.com.apeman.dal.DatafeedResultH\x00\x88\x01\x01\x42\x0b\n\t_datafeed\"\x1c\n\x0cResultAsJson\x12\x0c\n\x04json\x18\x01 \x01(\t*d\n\x08\x44\x61taType\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x08\n\x04TEXT\x10\x01\x12\x08\n\x04UUID\x10\x02\x12\r\n\tTIMESTAMP\x10\x03\x12\n\n\x06\x42IGINT\x10\x04\x12\x0b\n\x07\x42OOLEAN\x10\x05\x12\n\n\x06\x44OUBLE\x10\x06*@\n\nDataAmount\x12\x12\n\x0eUNKNOWN_AMOUNT\x10\x00\x12\t\n\x05SMALL\x10\x01\x12\n\n\x06MEDIUM\x10\x02\x12\x07\n\x03\x42IG\x10\x03\x32\xe9\x04\n\x0bTsdbService\x12_\n\x0e\x63reateDatafeed\x12%.com.apeman.dal.CreateDatafeedRequest\x1a&.com.apeman.dal.CreateDatafeedResponse\x12_\n\x0e\x64\x65leteDatafeed\x12%.com.apeman.dal.DeleteDatafeedRequest\x1a&.com.apeman.dal.DeleteDatafeedResponse\x12V\n\x0bgetDatafeed\x12\".com.apeman.dal.GetDatafeedRequest\x1a#.com.apeman.dal.GetDatafeedResponse\x12Y\n\x0clistDatafeed\x12#.com.apeman.dal.ListDatafeedRequest\x1a$.com.apeman.dal.ListDatafeedResponse\x12J\n\x07putData\x12\x1e.com.apeman.dal.PutDataRequest\x1a\x1f.com.apeman.dal.PutDataResponse\x12J\n\x07getData\x12\x1e.com.apeman.dal.GetDataRequest\x1a\x1f.com.apeman.dal.GetDataResponse\x12M\n\rgetDataAsJson\x12\x1e.com.apeman.dal.GetDataRequest\x1a\x1c.com.apeman.dal.ResultAsJsonB\x12\n\x0e\x63om.apeman.dalP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'apeman.dal.tsdb.tsdb_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.apeman.dalP\001'
  _DATATYPE._serialized_start=2089
  _DATATYPE._serialized_end=2189
  _DATAAMOUNT._serialized_start=2191
  _DATAAMOUNT._serialized_end=2255
  _COLUMNDEFINITION._serialized_start=47
  _COLUMNDEFINITION._serialized_end=183
  _UNIQUEKEY._serialized_start=185
  _UNIQUEKEY._serialized_end=210
  _CREATEDATAFEEDREQUEST._serialized_start=213
  _CREATEDATAFEEDREQUEST._serialized_end=460
  _CREATEDATAFEEDRESPONSE._serialized_start=462
  _CREATEDATAFEEDRESPONSE._serialized_end=486
  _TIMESTAMP._serialized_start=488
  _TIMESTAMP._serialized_end=522
  _VAL._serialized_start=525
  _VAL._serialized_end=660
  _COLUMNMETA._serialized_start=662
  _COLUMNMETA._serialized_end=728
  _TUPLE._serialized_start=730
  _TUPLE._serialized_end=772
  _TABULARDATA._serialized_start=774
  _TABULARDATA._serialized_end=869
  _PUTDATAREQUEST._serialized_start=871
  _PUTDATAREQUEST._serialized_end=948
  _PUTDATARESPONSE._serialized_start=950
  _PUTDATARESPONSE._serialized_end=967
  _OUTPUTCOLUMN._serialized_start=969
  _OUTPUTCOLUMN._serialized_end=1027
  _GETDATAREQUEST._serialized_start=1030
  _GETDATAREQUEST._serialized_end=1373
  _GETDATARESPONSE._serialized_start=1375
  _GETDATARESPONSE._serialized_end=1453
  _DELETEDATAFEEDREQUEST._serialized_start=1455
  _DELETEDATAFEEDREQUEST._serialized_end=1496
  _DELETEDATAFEEDRESPONSE._serialized_start=1498
  _DELETEDATAFEEDRESPONSE._serialized_end=1522
  _LISTDATAFEEDREQUEST._serialized_start=1524
  _LISTDATAFEEDREQUEST._serialized_end=1577
  _DATAFEEDRESULT._serialized_start=1580
  _DATAFEEDRESULT._serialized_end=1852
  _LISTDATAFEEDRESPONSE._serialized_start=1854
  _LISTDATAFEEDRESPONSE._serialized_end=1926
  _GETDATAFEEDREQUEST._serialized_start=1928
  _GETDATAFEEDREQUEST._serialized_end=1966
  _GETDATAFEEDRESPONSE._serialized_start=1968
  _GETDATAFEEDRESPONSE._serialized_end=2057
  _RESULTASJSON._serialized_start=2059
  _RESULTASJSON._serialized_end=2087
  _TSDBSERVICE._serialized_start=2258
  _TSDBSERVICE._serialized_end=2875
# @@protoc_insertion_point(module_scope)
